==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/ImageFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ImageFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.ImageFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.ImageFluent<A>{
  public ImageFluentImpl() {
  }
  public ImageFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.Image instance) {
    this.withChecksum(instance.getChecksum()); 
    this.withChecksumType(instance.getChecksumType()); 
    this.withFormat(instance.getFormat()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String checksum;
  private java.lang.String checksumType;
  private java.lang.String format;
  private java.lang.String url;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getChecksum() {
    return this.checksum;
  }
  public A withChecksum(java.lang.String checksum) {
    this.checksum=checksum; return (A) this;
  }
  public java.lang.Boolean hasChecksum() {
    return this.checksum != null;
  }
  
  /**
   * Method is deprecated. use withChecksum instead.
   */
  @java.lang.Deprecated
  public A withNewChecksum(java.lang.String arg0) {
    return (A)withChecksum(new String(arg0));
  }
  public java.lang.String getChecksumType() {
    return this.checksumType;
  }
  public A withChecksumType(java.lang.String checksumType) {
    this.checksumType=checksumType; return (A) this;
  }
  public java.lang.Boolean hasChecksumType() {
    return this.checksumType != null;
  }
  
  /**
   * Method is deprecated. use withChecksumType instead.
   */
  @java.lang.Deprecated
  public A withNewChecksumType(java.lang.String arg0) {
    return (A)withChecksumType(new String(arg0));
  }
  public java.lang.String getFormat() {
    return this.format;
  }
  public A withFormat(java.lang.String format) {
    this.format=format; return (A) this;
  }
  public java.lang.Boolean hasFormat() {
    return this.format != null;
  }
  
  /**
   * Method is deprecated. use withFormat instead.
   */
  @java.lang.Deprecated
  public A withNewFormat(java.lang.String arg0) {
    return (A)withFormat(new String(arg0));
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageFluentImpl that = (ImageFluentImpl) o;
    if (checksum != null ? !checksum.equals(that.checksum) :that.checksum != null) return false;
    if (checksumType != null ? !checksumType.equals(that.checksumType) :that.checksumType != null) return false;
    if (format != null ? !format.equals(that.format) :that.format != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(checksum,  checksumType,  format,  url,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-5.12.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/ImageFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ImageFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.ImageFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.ImageFluent<A>{
  public ImageFluentImpl() {
  }
  public ImageFluentImpl(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.Image instance) {
    this.withChecksum(instance.getChecksum()); 
    this.withChecksumType(instance.getChecksumType()); 
    this.withFormat(instance.getFormat()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String checksum;
  private java.lang.String checksumType;
  private java.lang.String format;
  private java.lang.String url;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getChecksum() {
    return this.checksum;
  }
  public A withChecksum(java.lang.String checksum) {
    this.checksum=checksum; return (A) this;
  }
  public java.lang.Boolean hasChecksum() {
    return this.checksum != null;
  }
  
  /**
   * Method is deprecated. use withChecksum instead.
   */
  @java.lang.Deprecated
  public A withNewChecksum(java.lang.String arg0) {
    return (A)withChecksum(new String(arg0));
  }
  public java.lang.String getChecksumType() {
    return this.checksumType;
  }
  public A withChecksumType(java.lang.String checksumType) {
    this.checksumType=checksumType; return (A) this;
  }
  public java.lang.Boolean hasChecksumType() {
    return this.checksumType != null;
  }
  
  /**
   * Method is deprecated. use withChecksumType instead.
   */
  @java.lang.Deprecated
  public A withNewChecksumType(java.lang.String arg0) {
    return (A)withChecksumType(new String(arg0));
  }
  public java.lang.String getFormat() {
    return this.format;
  }
  public A withFormat(java.lang.String format) {
    this.format=format; return (A) this;
  }
  public java.lang.Boolean hasFormat() {
    return this.format != null;
  }
  
  /**
   * Method is deprecated. use withFormat instead.
   */
  @java.lang.Deprecated
  public A withNewFormat(java.lang.String arg0) {
    return (A)withFormat(new String(arg0));
  }
  public java.lang.String getUrl() {
    return this.url;
  }
  public A withUrl(java.lang.String url) {
    this.url=url; return (A) this;
  }
  public java.lang.Boolean hasUrl() {
    return this.url != null;
  }
  
  /**
   * Method is deprecated. use withUrl instead.
   */
  @java.lang.Deprecated
  public A withNewUrl(java.lang.String arg0) {
    return (A)withUrl(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageFluentImpl that = (ImageFluentImpl) o;
    if (checksum != null ? !checksum.equals(that.checksum) :that.checksum != null) return false;
    if (checksumType != null ? !checksumType.equals(that.checksumType) :that.checksumType != null) return false;
    if (format != null ? !format.equals(that.format) :that.format != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(checksum,  checksumType,  format,  url,  additionalProperties,  super.hashCode());
  }
  
}
